@@ -1,7 +1,7 @@
 package App::FilterOrgByHeadlines;
 
-our $DATE = '2015-05-02'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010;
 use strict;
@@ -271,16 +271,18 @@ App::FilterOrgByHeadlines - Filter Org by headlines
 
 =head1 VERSION
 
-This document describes version 0.31 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-05-02.
+This document describes version 0.32 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-08-17.
 
 =head1 FUNCTIONS
 
 
 =head2 filter_org_by_headlines(%args) -> str|array[str]
 
-Filter Org by headlines.
+{en_US Filter Org by headlines}.
 
+{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -288,31 +290,37 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-Only include headline whose ascendant matches this.
+{en_US Only include headline whose ascendant matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<input>* => I<str>
 
+{en_US 
 Value is either a string or an array of strings.
+}
 
 =item * B<is_done> => I<bool>
 
-Only include headline which is a done todo item.
+{en_US Only include headline which is a done todo item}.
 
 =item * B<is_todo> => I<bool>
 
-Only include headline which is a todo item.
+{en_US Only include headline which is a todo item}.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-Only include headline which matches this.
+{en_US Only include headline which matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<max_level> => I<int>
 
@@ -320,22 +328,24 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-Only include headline whose parent matches this.
+{en_US Only include headline whose parent matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<return_array> => I<bool>
 
-Return array of strings instead of strings.
+{en_US Return array of strings instead of strings}.
 
 =item * B<with_content> => I<bool> (default: 1)
 
-Include headline content.
+{en_US Include headline content}.
 
 =item * B<with_preamble> => I<bool> (default: 1)
 
-Include text before any headline.
+{en_US Include text before any headline}.
 
 =back
 
@@ -347,7 +357,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
