@@ -1,13 +1,13 @@
 package App::ListOrgAnniversaries;
 
-our $DATE = '2015-05-02'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use App::OrgUtils;
 use Cwd qw(abs_path);
@@ -271,7 +271,7 @@ App::ListOrgAnniversaries - List all anniversaries in Org files
 
 =head1 VERSION
 
-This document describes version 0.31 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-05-02.
+This document describes version 0.32 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -282,9 +282,9 @@ This document describes version 0.31 of App::ListOrgAnniversaries (from Perl dis
 
 =head2 list_org_anniversaries(%args) -> [status, msg, result, meta]
 
-List all anniversaries in Org files.
+{en_US List all anniversaries in Org files}.
 
-This function expects contacts in the following format:
+{en_US This function expects contacts in the following format:
 
  * First last                              :office:friend:
    :PROPERTIES:
@@ -311,6 +311,7 @@ By default, all contacts' anniversaries will be listed. You can filter contacts
 using tags ('has_tags' and 'lacks_tags' options), or by 'due_in' and
 'max_overdue' options (due_in=14 and max_overdue=2 is what I commonly use in my
 startup script).
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -318,55 +319,63 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cache_dir> => I<str>
 
-Cache Org parse result.
+{en_US Cache Org parse result}.
 
+{en_US 
 Since Org::Parser can spend some time to parse largish Org files, this is an
 option to store the parse result. Caching is turned on if this argument is set.
+}
 
 =item * B<due_in> => I<int>
 
-Only show anniversaries that are due in this number of days.
+{en_US Only show anniversaries that are due in this number of days}.
 
 =item * B<field_pattern> => I<str> (default: "(?:birthday|anniversary)")
 
-Field regex that specifies anniversaries.
+{en_US Field regex that specifies anniversaries}.
 
 =item * B<files>* => I<array[str]>
 
 =item * B<has_tags> => I<array[str]>
 
-Filter headlines that have the specified tags.
+{en_US Filter headlines that have the specified tags}.
 
 =item * B<lacks_tags> => I<array[str]>
 
-Filter headlines that don't have the specified tags.
+{en_US Filter headlines that don't have the specified tags}.
 
 =item * B<max_overdue> => I<int>
 
-Don't show dates that are overdue more than this number of days.
+{en_US Don't show dates that are overdue more than this number of days}.
 
 =item * B<sort> => I<str|code> (default: "due_date")
 
-Specify sorting.
+{en_US Specify sorting}.
 
+{en_US 
 If string, must be one of 'date', '-date' (descending).
 
 If code, sorting code will get [REC, DUE_DATE] as the items to compare, where
 REC is the final record that will be returned as final result (can be a string
 or a hash, if 'detail' is enabled), and DUE_DATE is the DateTime object.
+}
 
 =item * B<time_zone> => I<str>
 
-Will be passed to parser's options.
+{en_US Will be passed to parser's options}.
 
+{en_US 
 If not set, TZ environment variable will be picked as default.
+}
 
 =item * B<today> => I<obj>
 
-Assume today's date.
+{en_US Assume today's date}.
 
+{en_US 
 You can provide Unix timestamp or DateTime object. If you provide a DateTime
 object, remember to set the correct time zone.
+}
 
 =back
 
@@ -387,7 +396,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
