@@ -1,7 +1,7 @@
 package App::ListOrgHeadlinesFast;
 
-our $DATE = '2015-05-02'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010;
 use strict;
@@ -96,16 +96,18 @@ App::ListOrgHeadlinesFast - List & count Org headlines & todos
 
 =head1 VERSION
 
-This document describes version 0.31 of App::ListOrgHeadlinesFast (from Perl distribution App-OrgUtils), released on 2015-05-02.
+This document describes version 0.32 of App::ListOrgHeadlinesFast (from Perl distribution App-OrgUtils), released on 2015-08-17.
 
 =head1 FUNCTIONS
 
 
 =head2 count_org_headlines(%args) -> int
 
-Count Org headlines.
+{en_US Count Org headlines}.
 
+{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -113,31 +115,37 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-Only include headline whose ascendant matches this.
+{en_US Only include headline whose ascendant matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<input>* => I<str>
 
+{en_US 
 Value is either a string or an array of strings.
+}
 
 =item * B<is_done> => I<bool>
 
-Only include headline which is a done todo item.
+{en_US Only include headline which is a done todo item}.
 
 =item * B<is_todo> => I<bool>
 
-Only include headline which is a todo item.
+{en_US Only include headline which is a todo item}.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-Only include headline which matches this.
+{en_US Only include headline which matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<max_level> => I<int>
 
@@ -145,10 +153,12 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-Only include headline whose parent matches this.
+{en_US Only include headline whose parent matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =back
 
@@ -157,9 +167,11 @@ Return value:  (int)
 
 =head2 count_org_todos(%args) -> int
 
-Count Org todos.
+{en_US Count Org todos}.
 
+{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -167,27 +179,33 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-Only include headline whose ascendant matches this.
+{en_US Only include headline whose ascendant matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<input>* => I<str>
 
+{en_US 
 Value is either a string or an array of strings.
+}
 
 =item * B<is_done> => I<bool>
 
-Only include headline which is a done todo item.
+{en_US Only include headline which is a done todo item}.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-Only include headline which matches this.
+{en_US Only include headline which matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<max_level> => I<int>
 
@@ -195,10 +213,12 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-Only include headline whose parent matches this.
+{en_US Only include headline whose parent matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =back
 
@@ -207,9 +227,11 @@ Return value:  (int)
 
 =head2 list_org_headlines(%args) -> array[str]
 
-List Org headlines.
+{en_US List Org headlines}.
 
+{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -217,31 +239,37 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-Only include headline whose ascendant matches this.
+{en_US Only include headline whose ascendant matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<input>* => I<str>
 
+{en_US 
 Value is either a string or an array of strings.
+}
 
 =item * B<is_done> => I<bool>
 
-Only include headline which is a done todo item.
+{en_US Only include headline which is a done todo item}.
 
 =item * B<is_todo> => I<bool>
 
-Only include headline which is a todo item.
+{en_US Only include headline which is a todo item}.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-Only include headline which matches this.
+{en_US Only include headline which matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<max_level> => I<int>
 
@@ -249,10 +277,12 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-Only include headline whose parent matches this.
+{en_US Only include headline whose parent matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =back
 
@@ -261,9 +291,11 @@ Return value:  (array[str])
 
 =head2 list_org_todos(%args) -> array[str]
 
-List Org todos.
+{en_US List Org todos}.
 
+{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -271,27 +303,33 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-Only include headline whose ascendant matches this.
+{en_US Only include headline whose ascendant matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<input>* => I<str>
 
+{en_US 
 Value is either a string or an array of strings.
+}
 
 =item * B<is_done> => I<bool>
 
-Only include headline which is a done todo item.
+{en_US Only include headline which is a done todo item}.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-Only include headline which matches this.
+{en_US Only include headline which matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =item * B<max_level> => I<int>
 
@@ -299,10 +337,12 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-Only include headline whose parent matches this.
+{en_US Only include headline whose parent matches this}.
 
+{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
+}
 
 =back
 
@@ -314,7 +354,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
