@@ -1,12 +1,12 @@
 package App::OrgUtils;
 
-our $DATE = '2015-05-02'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Org::Parser;
 
@@ -188,7 +188,7 @@ App::OrgUtils - Some utilities for Org documents
 
 =head1 VERSION
 
-This document describes version 0.31 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-05-02.
+This document describes version 0.32 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-08-17.
 
 =head1 DESCRIPTION
 
@@ -200,24 +200,16 @@ following are the included scripts:
 
 =item * L<count-done-org-todos>
 
-=item * L<count-org-headlines-fast>
-
 =item * L<count-org-todos>
 
-=item * L<count-org-todos-fast>
-
 =item * L<count-undone-org-todos>
 
 =item * L<dump-org-structure>
 
-=item * L<filter-org-by-headlines>
-
 =item * L<list-org-anniversaries>
 
 =item * L<list-org-headlines>
 
-=item * L<list-org-headlines-fast>
-
 =item * L<list-org-priorities>
 
 =item * L<list-org-tags>
@@ -226,8 +218,6 @@ following are the included scripts:
 
 =item * L<list-org-todos>
 
-=item * L<list-org-todos-fast>
-
 =back
 
 =head1 SEE ALSO
@@ -240,7 +230,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
